@@ -68,7 +68,59 @@ class Locator(metaclass=LocatorMeta):
 
 
 @dataclass
-class ImageTemplate(Locator):
+class PointLocator(Locator):
+    """Locator for absolute coordinates."""
+
+    x: int
+    y: int
+
+    @property
+    def typename(self):
+        return "coordinates"
+
+    def __post_init__(self):
+        self.x = int(self.x)
+        self.y = int(self.y)
+
+
+@dataclass
+class OffsetLocator(Locator):
+    """Locator for offset coordinates."""
+
+    x: int
+    y: int
+
+    @property
+    def typename(self):
+        return "offset"
+
+    def __post_init__(self):
+        self.x = int(self.x)
+        self.y = int(self.y)
+
+
+@dataclass
+class RegionLocator(Locator):
+    """Locator for area defined by coordinates."""
+
+    left: int
+    top: int
+    right: int
+    bottom: int
+
+    @property
+    def typename(self):
+        return "area"
+
+    def __post_init__(self):
+        self.left = int(self.left)
+        self.top = int(self.top)
+        self.right = int(self.right)
+        self.bottom = int(self.bottom)
+
+
+@dataclass
+class ImageLocator(Locator):
     """Image-based locator for template matching."""
 
     path: Path
@@ -85,7 +137,24 @@ class ImageTemplate(Locator):
 
 
 @dataclass
-class BrowserDOM(Locator):
+class OcrLocator(Locator):
+    """Locator for OCR-based text."""
+
+    text: str
+    confidence: Optional[float] = None
+
+    @property
+    def typename(self):
+        return "ocr"
+
+    def __post_init__(self):
+        self.text = str(self.text)
+        if self.confidence is not None:
+            self.confidence = float(self.confidence)
+
+
+@dataclass
+class BrowserLocator(Locator):
     """Browser-based locator for DOM elements."""
 
     strategy: str
@@ -98,33 +167,8 @@ class BrowserDOM(Locator):
         return "browser"
 
 
-@dataclass
-class Coordinates(Locator):
-    """Locator for absolute coordinates."""
-
-    x: int
-    y: int
-
-    @property
-    def typename(self):
-        return "coordinates"
-
-    def __post_init__(self):
-        self.x = int(self.x)
-        self.y = int(self.y)
-
-
-@dataclass
-class Offset(Locator):
-    """Locator for offset coordinates."""
-
-    x: int
-    y: int
-
-    @property
-    def typename(self):
-        return "offset"
-
-    def __post_init__(self):
-        self.x = int(self.x)
-        self.y = int(self.y)
+# Aliases for backwards compatibility, just in case.
+Coordinates = PointLocator
+Offset = OffsetLocator
+BrowserDOM = BrowserLocator
+ImageTemplate = ImageLocator
